Learn R Programming

woodValuationDE (version 1.0.2)

get_species_codes: Available species in woodValuationDE, their codes, and parameter assignments

Description

The function returns the available species, species codes, and assignments of species to species groups for the economic valuation.

Usage

get_species_codes(method = "fuchs.orig")

Value

A list with the species, species codes, and assignments to economic species groups available in woodValuationDE.

Arguments

method

argument that is currently not used, but offers the possibility to implement alternative parameters and functions in the future.

Examples

Run this code
get_species_codes()

Run the code above in your browser using DataLab