wood_valuation(1,
40,
"beech")
# species codes Lower Saxony (Germany)
wood_valuation(seq(10, 70, 20),
40,
211,
species.code.type = "nds")
# vector input
wood_valuation(10,
seq(20, 50, 5),
"spruce")
wood_valuation(10,
40,
rep(c("beech", "spruce"),
each = 9),
value.level = rep(rep(1:3, 2),
each = 3),
cost.level = rep(1:3, 6))
wood_valuation(10,
40,
rep("spruce", 6),
calamity.type = c("none",
"ips.fuchs.2022a",
"ips.timely.fuchs.2022a",
"stand.damage.fuchs.2022b",
"regional.disturbance.fuchs.2022b",
"transregional.calamity.fuchs.2022b"))
# user-defined calamities with respective changes in harvest costs and wood revenues
wood_valuation(10,
40,
rep("spruce", 3),
calamity.type = c("none",
"my.own.calamity.1",
"my.own.calamity.2"),
calamity.factors = dplyr::tibble(
calamity.type = rep(c("none",
"my.own.calamity.1",
"my.own.calamity.2"),
each = 2),
species.group = rep(c("softwood",
"deciduous"),
times = 3),
revenues.factor = c(1.0, 1.0,
0.8, 0.8,
0.2, 0.2),
cost.factor = c(1.0, 1.0,
1.5, 1.5,
1.0, 1.0),
cost.additional = c(0, 0,
0, 0,
5, 5)))
# adapted market situation by providing alternative prices for the reference assortments
wood_valuation(10,
40,
c("oak", "beech", "spruce"))
wood_valuation(10,
40,
c("oak", "beech", "spruce"),
price.ref.assortment = dplyr::tibble(
species = c("oak", "beech", "spruce"),
price.ref.assortment = c(300, 80, 50)))
Run the code above in your browser using DataLab